@@ -22,16 +22,17 @@ from lfs.core.utils import LazyEncoder
 from lfs.customer.models import Customer
 from lfs.order.models import Order
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def customer(request, customer_id, template_name="manage/customer/customer.html"):
     """Displays customer with provided customer id.
     """
     return render_to_response(template_name, RequestContext(request, {
-        "customer_inline" : customer_inline(request, customer_id, as_string=True),
-        "selectable_customers_inline" : selectable_customers_inline(request, customer_id, as_string=True),
-    }));
+        "customer_inline": customer_inline(request, customer_id, as_string=True),
+        "selectable_customers_inline": selectable_customers_inline(request, customer_id, as_string=True),
+    }))
+
 
-@permission_required("core.manage_shop", login_url="/login/")
 def customer_inline(request, customer_id, as_string=False, template_name="manage/customer/customer_inline.html"):
     """Displays customer with provided customer id.
     """
@@ -41,17 +42,27 @@ def customer_inline(request, customer_id, as_string=False, template_name="manage
 
     try:
         cart = Cart.objects.get(session=customer.session)
-        cart_price = lfs.cart.utils.get_cart_price(request, cart, total=True)
+        cart_price = cart.get_price_gross(request)
     except Cart.DoesNotExist:
         cart = None
         cart_price = None
+    else:
+        # Shipping
+        selected_shipping_method = lfs.shipping.utils.get_selected_shipping_method(request)
+        shipping_costs = lfs.shipping.utils.get_shipping_costs(request, selected_shipping_method)
+
+        # Payment
+        selected_payment_method = lfs.payment.utils.get_selected_payment_method(request)
+        payment_costs = lfs.payment.utils.get_payment_costs(request, selected_payment_method)
+
+        cart_price = cart.get_price_gross(request) + shipping_costs["price"] + payment_costs["price"]
 
     result = render_to_string(template_name, RequestContext(request, {
-        "customer" : customer,
-        "orders" : orders,
-        "cart" : cart,
-        "cart_price" : cart_price,
-        "name" : customer_filters.get("name", ""),
+        "customer": customer,
+        "orders": orders,
+        "cart": cart,
+        "cart_price": cart_price,
+        "name": customer_filters.get("name", ""),
     }))
 
     if as_string:
@@ -60,19 +71,21 @@ def customer_inline(request, customer_id, as_string=False, template_name="manage
         html = (("#customer-inline", result),)
 
         result = simplejson.dumps({
-            "html" : html,
-        }, cls = LazyEncoder)
+            "html": html,
+        }, cls=LazyEncoder)
 
         return HttpResponse(result)
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def customers(request, template_name="manage/customer/customers.html"):
     """Base view to display customers overview.
     """
     return render_to_response(template_name, RequestContext(request, {
-        "customers_inline" : customers_inline(request, as_string=True),
+        "customers_inline": customers_inline(request, as_string=True),
     }))
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def customers_inline(request, as_string=False, template_name="manage/customer/customers_inline.html"):
     """Displays carts overview.
@@ -91,24 +104,24 @@ def customers_inline(request, as_string=False, template_name="manage/customer/cu
     for customer in page.object_list:
         try:
             cart = Cart.objects.get(session=customer.session)
-            cart_price = lfs.cart.utils.get_cart_price(request, cart, total=True)
+            cart_price = cart.get_price_gross(request, total=True)
         except Cart.DoesNotExist:
             cart_price = None
 
         orders = Order.objects.filter(session=customer.session)
         customers.append({
-            "customer" : customer,
-            "orders" : len(orders),
-            "cart_price" : cart_price,
+            "customer": customer,
+            "orders": len(orders),
+            "cart_price": cart_price,
         })
 
     result = render_to_string(template_name, RequestContext(request, {
-        "customers" : customers,
-        "page" : page,
-        "paginator" : paginator,
-        "start" : customer_filters.get("start", ""),
-        "end" : customer_filters.get("end", ""),
-        "ordering" : ordering,
+        "customers": customers,
+        "page": page,
+        "paginator": paginator,
+        "start": customer_filters.get("start", ""),
+        "end": customer_filters.get("end", ""),
+        "ordering": ordering,
     }))
 
     if as_string:
@@ -117,12 +130,12 @@ def customers_inline(request, as_string=False, template_name="manage/customer/cu
         html = (("#customers-inline", result),)
 
         result = simplejson.dumps({
-            "html" : html,
-        }, cls = LazyEncoder)
+            "html": html,
+        }, cls=LazyEncoder)
 
         return HttpResponse(result)
 
-@permission_required("core.manage_shop", login_url="/login/")
+
 def selectable_customers_inline(request, customer_id=0, as_string=False,
     template_name="manage/customer/selectable_customers_inline.html"):
     """Display selectable customers.
@@ -139,21 +152,21 @@ def selectable_customers_inline(request, customer_id=0, as_string=False,
     page = paginator.page(page)
 
     result = render_to_string(template_name, RequestContext(request, {
-        "paginator" : paginator,
-        "page" : page,
-        "customer_id" : int(customer_id),
+        "paginator": paginator,
+        "page": page,
+        "customer_id": int(customer_id),
     }))
 
     if as_string:
         return result
     else:
         result = simplejson.dumps({
-            "html" : (("#selectable-customers-inline", result),),
-        }, cls = LazyEncoder)
+            "html": (("#selectable-customers-inline", result),),
+        }, cls=LazyEncoder)
 
         return HttpResponse(result)
 
-@permission_required("core.manage_shop", login_url="/login/")
+
 def set_ordering(request, ordering):
     """Sets customer ordering given by passed request.
     """
@@ -183,12 +196,12 @@ def set_ordering(request, ordering):
         html = (("#customers-inline", customers_inline(request, as_string=True)),)
 
     result = simplejson.dumps({
-        "html" : html,
-    }, cls = LazyEncoder)
+        "html": html,
+    }, cls=LazyEncoder)
 
     return HttpResponse(result)
 
-@permission_required("core.manage_shop", login_url="/login/")
+
 def set_customer_filters(request):
     """Sets customer filters given by passed request.
     """
@@ -214,17 +227,17 @@ def set_customer_filters(request):
     msg = _(u"Customer filters have been set")
 
     result = simplejson.dumps({
-        "html" : html,
-        "message" : msg,
-    }, cls = LazyEncoder)
+        "html": html,
+        "message": msg,
+    }, cls=LazyEncoder)
 
     return HttpResponse(result)
 
-@permission_required("core.manage_shop", login_url="/login/")
+
 def reset_customer_filters(request):
     """Resets all customer filters.
     """
-    if request.session.has_key("customer-filters"):
+    if "customer-filters" in request.session:
         del request.session["customer-filters"]
 
     if request.REQUEST.get("came-from") == "customer":
@@ -239,12 +252,13 @@ def reset_customer_filters(request):
     msg = _(u"Customer filters has been reset")
 
     result = simplejson.dumps({
-        "html" : html,
-        "message" : msg,
-    }, cls = LazyEncoder)
+        "html": html,
+        "message": msg,
+    }, cls=LazyEncoder)
 
     return HttpResponse(result)
 
+
 def _get_filtered_customers(request, customer_filters):
     """
     """
@@ -256,7 +270,7 @@ def _get_filtered_customers(request, customer_filters):
     # Filter
     name = customer_filters.get("name", "")
     if name != "":
-        f  = Q(selected_invoice_address__lastname__icontains=name)
+        f = Q(selected_invoice_address__lastname__icontains=name)
         f |= Q(selected_invoice_address__firstname__icontains=name)
         customers = customers.filter(f)
 
