@@ -16,6 +16,7 @@ from django.template.loader import render_to_string
 from django.template import RequestContext
 from django.utils import simplejson
 from django.utils.translation import ugettext_lazy as _
+from django.views.decorators.http import require_POST
 
 # lfs imports
 import lfs.core.utils
@@ -26,6 +27,7 @@ from lfs.core.utils import LazyEncoder
 from lfs.mail import utils as mail_utils
 from lfs.order.models import Order
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def manage_orders(request, template_name="manage/order/manage_orders.html"):
     """Dispatches to the first order or the order overview.
@@ -36,17 +38,18 @@ def manage_orders(request, template_name="manage/order/manage_orders.html"):
         return HttpResponseRedirect(reverse("lfs_orders"))
     else:
         return HttpResponseRedirect(
-            reverse("lfs_manage_order", kwargs={"order_id" : order.id}))
+            reverse("lfs_manage_order", kwargs={"order_id": order.id}))
+
 
 @permission_required("core.manage_shop", login_url="/login/")
 def orders_view(request, template_name="manage/order/orders.html"):
     """Main view to display an order overview.
     """
     return render_to_response(template_name, RequestContext(request, {
-        "orders_inline" : orders_inline(request, as_string=True),
+        "orders_inline": orders_inline(request, as_string=True),
     }))
 
-@permission_required("core.manage_shop", login_url="/login/")
+
 def orders_inline(request, as_string=False, template_name="manage/order/orders_inline.html"):
     """Displays the orders. This is factored out in order to reload it via
     ajax request.
@@ -67,18 +70,18 @@ def orders_inline(request, as_string=False, template_name="manage/order/orders_i
     state_id = order_filters.get("state")
     for state in lfs.order.settings.ORDER_STATES:
         states.append({
-            "id"   : state[0],
-            "name" : state[1],
-            "selected" : state_id == str(state[0]),
+            "id": state[0],
+            "name": state[1],
+            "selected": state_id == str(state[0]),
         })
 
     result = render_to_string(template_name, RequestContext(request, {
-        "paginator" : paginator,
-        "page" : page,
-        "states" : states,
-        "start" : order_filters.get("start", ""),
-        "end" : order_filters.get("end", ""),
-        "name" : order_filters.get("name", ""),
+        "paginator": paginator,
+        "page": page,
+        "states": states,
+        "start": order_filters.get("start", ""),
+        "end": order_filters.get("end", ""),
+        "name": order_filters.get("name", ""),
     }))
 
     if as_string:
@@ -87,12 +90,12 @@ def orders_inline(request, as_string=False, template_name="manage/order/orders_i
         html = (("#orders-inline", result),)
 
         result = simplejson.dumps({
-            "html" : html,
-        }, cls = LazyEncoder)
+            "html": html,
+        }, cls=LazyEncoder)
 
         return HttpResponse(result)
 
-@permission_required("core.manage_shop", login_url="/login/")
+
 def set_order_filters(request):
     """Sets order filters given by passed request.
     """
@@ -136,13 +139,13 @@ def set_order_filters(request):
     msg = _(u"Filters has been set")
 
     result = simplejson.dumps({
-        "html" : html,
-        "message" : msg,
-    }, cls = LazyEncoder)
+        "html": html,
+        "message": msg,
+    }, cls=LazyEncoder)
 
     return HttpResponse(result)
 
-@permission_required("core.manage_shop", login_url="/login/")
+
 def set_order_filters_date(request):
     """Sets the date filter by given short cut link
     """
@@ -167,17 +170,17 @@ def set_order_filters_date(request):
     msg = _(u"Filters has been set")
 
     result = simplejson.dumps({
-        "html" : html,
-        "message" : msg,
-    }, cls = LazyEncoder)
+        "html": html,
+        "message": msg,
+    }, cls=LazyEncoder)
 
     return HttpResponse(result)
 
-@permission_required("core.manage_shop", login_url="/login/")
+
 def reset_order_filters(request):
     """resets order filter.
     """
-    if request.session.has_key("order-filters"):
+    if "order-filters" in request.session:
         del request.session["order-filters"]
 
     if request.REQUEST.get("came-from") == "order":
@@ -192,24 +195,17 @@ def reset_order_filters(request):
     msg = _(u"Filters has been reset")
 
     result = simplejson.dumps({
-        "html" : html,
-        "message" : msg,
-    }, cls = LazyEncoder)
+        "html": html,
+        "message": msg,
+    }, cls=LazyEncoder)
 
     return HttpResponse(result)
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def order_view(request, order_id, template_name="manage/order/order.html"):
     """Displays order with provided order id.
     """
-    return render_to_response(template_name, RequestContext(request, {
-        "order_inline" : order_inline(request, order_id, as_string=True),
-        "selectable_orders" : selectable_orders_inline(request, as_string=True),
-    }));
-
-def order_inline(request, order_id, as_string=False, template_name="manage/order/order_inline.html"):
-    """
-    """
     order_filters = request.session.get("order-filters", {})
     order = lfs_get_object_or_404(Order, pk=order_id)
 
@@ -217,18 +213,42 @@ def order_inline(request, order_id, as_string=False, template_name="manage/order
     state_id = order_filters.get("state")
     for state in lfs.order.settings.ORDER_STATES:
         states.append({
-            "id"   : state[0],
-            "name" : state[1],
-            "selected_filter" : state_id == str(state[0]),
-            "selected_order" : order.state == state[0],
+            "id": state[0],
+            "name": state[1],
+            "selected_filter": state_id == str(state[0]),
+            "selected_order": order.state == state[0],
+        })
+
+    return render_to_response(template_name, RequestContext(request, {
+        "order_inline": order_inline(request, order_id, as_string=True),
+        "selectable_orders": selectable_orders_inline(request, as_string=True),
+        "current_order" : order,
+        "states": states,
+    }))
+
+
+def order_inline(request, order_id, as_string=False, template_name="manage/order/order_inline.html"):
+    """Displays the details of an order.
+    """
+    order_filters = request.session.get("order-filters", {})
+    order = lfs_get_object_or_404(Order, pk=order_id)
+
+    states = []
+    state_id = order_filters.get("state")
+    for state in lfs.order.settings.ORDER_STATES:
+        states.append({
+            "id": state[0],
+            "name": state[1],
+            "selected_filter": state_id == str(state[0]),
+            "selected_order": order.state == state[0],
         })
 
     result = render_to_string(template_name, RequestContext(request, {
-        "current_order" : order,
-        "start" : order_filters.get("start", ""),
-        "end" : order_filters.get("end", ""),
-        "name" : order_filters.get("name", ""),
-        "states" : states,
+        "current_order": order,
+        "start": order_filters.get("start", ""),
+        "end": order_filters.get("end", ""),
+        "name": order_filters.get("name", ""),
+        "states": states,
     }))
 
     if as_string:
@@ -236,6 +256,7 @@ def order_inline(request, order_id, as_string=False, template_name="manage/order
     else:
         return HttpResponse(result)
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def selectable_orders_inline(request, as_string=False,
     template_name="manage/order/selectable_orders_inline.html"):
@@ -254,21 +275,23 @@ def selectable_orders_inline(request, as_string=False,
     page = paginator.page(page)
 
     result = render_to_string(template_name, RequestContext(request, {
-        "orders" : orders,
-        "paginator" : paginator,
-        "page" : page,
+        "orders": orders,
+        "paginator": paginator,
+        "page": page,
     }))
 
     if as_string:
         return result
     else:
         result = simplejson.dumps({
-            "html" : (("#selectable-orders", result),),
-        }, cls = LazyEncoder)
+            "html": (("#selectable-orders", result),),
+        }, cls=LazyEncoder)
 
         return HttpResponse(result)
 
+
 # Actions
+@require_POST
 @permission_required("core.manage_shop", login_url="/login/")
 def delete_order(request, order_id):
     """Deletes order with provided order id.
@@ -278,12 +301,13 @@ def delete_order(request, order_id):
 
     try:
         order = Order.objects.all()[0]
-        url = reverse("lfs_manage_order", kwargs={"order_id" : order.id})
+        url = reverse("lfs_manage_order", kwargs={"order_id": order.id})
     except IndexError:
         url = reverse("lfs_manage_orders")
 
     return HttpResponseRedirect(url)
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def send_order(request, order_id):
     """Sends order with passed order id to the customer of this order.
@@ -292,11 +316,11 @@ def send_order(request, order_id):
     mail_utils.send_order_received_mail(order)
 
     return lfs.core.utils.set_message_cookie(
-        url = reverse("lfs_manage_order", kwargs={"order_id" : order.id}),
-        msg = _(u"Order has been sent."),
+        url=reverse("lfs_manage_order", kwargs={"order_id": order.id}),
+        msg=_(u"Order has been sent."),
     )
 
-@permission_required("core.manage_shop", login_url="/login/")
+
 def change_order_state(request):
     """Changes the state of an order, given by request post variables.
     """
@@ -313,7 +337,7 @@ def change_order_state(request):
         order.save()
 
     if order.state == lfs.order.settings.SENT:
-        lfs.core.signals.order_sent.send({"order" : order, "request" : request})
+        lfs.core.signals.order_sent.send({"order": order, "request": request})
 
     msg = _(u"State has been changed")
 
@@ -323,12 +347,13 @@ def change_order_state(request):
     )
 
     result = simplejson.dumps({
-        "html" : html,
-        "message" : msg,
-    }, cls = LazyEncoder)
+        "html": html,
+        "message": msg,
+    }, cls=LazyEncoder)
 
     return HttpResponse(result)
 
+
 def _get_filtered_orders(order_filters):
     """
     """
@@ -337,7 +362,7 @@ def _get_filtered_orders(order_filters):
     # name
     name = order_filters.get("name", "")
     if name != "":
-        f  = Q(customer_lastname__icontains=name)
+        f = Q(customer_lastname__icontains=name)
         f |= Q(customer_firstname__icontains=name)
         orders = orders.filter(f)
 
