@@ -1,15 +1,19 @@
 # django imports
+from django.conf import settings
 from django.contrib.auth.decorators import permission_required
 from django.core.cache import cache
 from django.core.exceptions import ObjectDoesNotExist
+from django.db import IntegrityError
 from django.forms import ModelForm
 from django.http import HttpResponse
 from django.template import RequestContext
 from django.template.defaultfilters import slugify
 from django.template.loader import render_to_string
 from django.utils import simplejson
+from django.utils.translation import ugettext_lazy as _
 
 # lfs imports
+import lfs.catalog.utils
 from lfs.caching.utils import lfs_get_object_or_404
 from lfs.core.signals import product_changed
 from lfs.catalog.models import Product
@@ -20,7 +24,7 @@ from lfs.catalog.models import PropertyGroup
 from lfs.catalog.models import PropertyOption
 from lfs.catalog.settings import VARIANT, PROPERTY_SELECT_FIELD
 from lfs.catalog.settings import PROPERTY_VALUE_TYPE_VARIANT
-import lfs.catalog.utils
+from lfs.core.utils import LazyEncoder
 from lfs.manage import utils as manage_utils
 
 
@@ -31,6 +35,7 @@ class PropertyOptionForm(ModelForm):
         model = PropertyOption
         fields = ("name", )
 
+
 class PropertyForm(ModelForm):
     """Form to add/edit properties.
     """
@@ -38,6 +43,7 @@ class PropertyForm(ModelForm):
         model = Property
         fields = ("name", )
 
+
 class ProductVariantSimpleForm(ModelForm):
     """Form to add/edit variants options.
     """
@@ -45,6 +51,7 @@ class ProductVariantSimpleForm(ModelForm):
         model = Product
         fields = ("slug", "name", "price", )
 
+
 class DisplayTypeForm(ModelForm):
     """Form to add/edit product's sub types.
     """
@@ -52,6 +59,7 @@ class DisplayTypeForm(ModelForm):
         model = Product
         fields = ("variants_display_type", )
 
+
 class DefaultVariantForm(ModelForm):
     """Form to edit the default variant.
     """
@@ -68,6 +76,7 @@ class DefaultVariantForm(ModelForm):
         model = Product
         fields = ("default_variant", )
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def manage_variants(request, product_id, as_string=False, template_name="manage/product/variants.html"):
     """Manages the variants of a product.
@@ -81,7 +90,7 @@ def manage_variants(request, product_id, as_string=False, template_name="manage/
     default_variant_form = DefaultVariantForm(instance=product)
 
     # TODO: Delete cache when delete options
-    cache_key = "manage-properties-variants-%s" % product_id
+    cache_key = "%s-manage-properties-variants-%s" % (settings.CACHE_MIDDLEWARE_KEY_PREFIX, product_id)
     variants = cache.get(cache_key)
     # Get all properties. We need to traverse through all property / options
     # in order to select the options of the current variant.
@@ -89,7 +98,7 @@ def manage_variants(request, product_id, as_string=False, template_name="manage/
         variants = []
         for variant in product.variants.all().order_by("variant_position"):
             properties = []
-            for property in product.get_properties():
+            for property in product.get_property_select_fields():
                 options = []
                 for property_option in property.options.all():
                     if variant.has_option(property, property_option):
@@ -97,27 +106,28 @@ def manage_variants(request, product_id, as_string=False, template_name="manage/
                     else:
                         selected = False
                     options.append({
-                        "id"   : property_option.id,
-                        "name" : property_option.name,
-                        "selected" : selected
+                        "id": property_option.id,
+                        "name": property_option.name,
+                        "selected": selected
                     })
                 properties.append({
-                    "id" : property.id,
-                    "name" : property.name,
-                    "options" : options
+                    "id": property.id,
+                    "name": property.name,
+                    "options": options
                 })
 
             variants.append({
-                "id" : variant.id,
-                "active" : variant.active,
-                "slug" : variant.slug,
-                "sku" : variant.sku,
-                "name" : variant.name,
-                "active_name" : variant.active_name,
-                "price" : variant.price,
-                "active_price" : variant.active_price,
-                "position" : variant.variant_position,
-                "properties" : properties
+                "id": variant.id,
+                "active": variant.active,
+                "slug": variant.slug,
+                "sku": variant.sku,
+                "name": variant.name,
+                "price": variant.price,
+                "active_price": variant.active_price,
+                "active_sku": variant.active_sku,
+                "active_name": variant.active_name,
+                "position": variant.variant_position,
+                "properties": properties
             })
 
         cache.set(cache_key, variants)
@@ -128,22 +138,22 @@ def manage_variants(request, product_id, as_string=False, template_name="manage/
     for property_group in PropertyGroup.objects.all():
 
         shop_property_groups.append({
-            "id" : property_group.id,
-            "name" : property_group.name,
-            "selected" : property_group.id in product_property_group_ids,
+            "id": property_group.id,
+            "name": property_group.name,
+            "selected": property_group.id in product_property_group_ids,
         })
 
     result = render_to_string(template_name, RequestContext(request, {
-        "product" : product,
-        "variants" : variants,
-        "shop_property_groups" : shop_property_groups,
-        "local_properties" : product.get_local_properties(),
-        "all_properties" : product.get_properties(),
-        "property_option_form" : property_option_form,
-        "property_form" : property_form,
-        "variant_simple_form" : variant_simple_form,
-        "display_type_form" : display_type_form,
-        "default_variant_form" : default_variant_form,
+        "product": product,
+        "variants": variants,
+        "shop_property_groups": shop_property_groups,
+        "local_properties": product.get_local_properties(),
+        "all_properties": product.get_property_select_fields(),
+        "property_option_form": property_option_form,
+        "property_form": property_form,
+        "variant_simple_form": variant_simple_form,
+        "display_type_form": display_type_form,
+        "default_variant_form": default_variant_form,
     }))
 
     if as_string:
@@ -151,6 +161,7 @@ def manage_variants(request, product_id, as_string=False, template_name="manage/
     else:
         return HttpResponse(result)
 
+
 # Actions
 @permission_required("core.manage_shop", login_url="/login/")
 def add_property(request, product_id):
@@ -178,7 +189,15 @@ def add_property(request, product_id):
             product_property.position = i
             product_property.save()
 
-    return HttpResponse(manage_variants(request, product_id))
+    html = [["#variants", manage_variants(request, product_id, as_string=True)]]
+
+    result = simplejson.dumps({
+        "html": html,
+        "message": _(u"Property has been added."),
+    }, cls=LazyEncoder)
+
+    return HttpResponse(result)
+
 
 @permission_required("core.manage_shop", login_url="/login/")
 def delete_property(request, product_id, property_id):
@@ -192,7 +211,16 @@ def delete_property(request, product_id, property_id):
     else:
         property.delete()
 
-    return HttpResponse(manage_variants(request, product_id))
+    html = (("#variants", manage_variants(request, product_id, as_string=True)),)
+
+    result = simplejson.dumps({
+        "html": html,
+        "message": _(u"Property has been deleted."),
+        "close-dialog": True,
+    }, cls=LazyEncoder)
+
+    return HttpResponse(result)
+
 
 @permission_required("core.manage_shop", login_url="/login/")
 def change_property_position(request):
@@ -203,7 +231,7 @@ def change_property_position(request):
     direction = request.GET.get("direction")
 
     try:
-        product_property = ProductsPropertiesRelation.objects.get(product = product_id, property = property_id)
+        product_property = ProductsPropertiesRelation.objects.get(product=product_id, property=property_id)
     except ObjectDoesNotExist:
         pass
     else:
@@ -216,7 +244,14 @@ def change_property_position(request):
 
     _refresh_property_positions(product_id)
 
-    return HttpResponse(manage_variants(request, product_id))
+    html = (("#variants", manage_variants(request, product_id, as_string=True)),)
+
+    result = simplejson.dumps({
+        "html": html,
+    }, cls=LazyEncoder)
+
+    return HttpResponse(result)
+
 
 @permission_required("core.manage_shop", login_url="/login/")
 def add_property_option(request, product_id):
@@ -239,11 +274,19 @@ def add_property_option(request, product_id):
             position += 1
 
         # Refresh positions
-        for i, option in enumerate(PropertyOption.objects.filter(property = property_option.property)):
+        for i, option in enumerate(PropertyOption.objects.filter(property=property_option.property)):
             option.position = i
             option.save()
 
-    return HttpResponse(manage_variants(request, product_id))
+    html = [["#variants", manage_variants(request, product_id, as_string=True)]]
+
+    result = simplejson.dumps({
+        "html": html,
+        "message": _(u"Option has been added."),
+    }, cls=LazyEncoder)
+
+    return HttpResponse(result)
+
 
 @permission_required("core.manage_shop", login_url="/login/")
 def delete_property_option(request, product_id, option_id):
@@ -257,14 +300,23 @@ def delete_property_option(request, product_id, option_id):
     else:
         property_option.delete()
 
-    return HttpResponse(manage_variants(request, product_id))
+    html = (("#variants", manage_variants(request, product_id, as_string=True)),)
+
+    result = simplejson.dumps({
+        "html": html,
+        "message": _(u"Property has been deleted."),
+        "close-dialog": True,
+    }, cls=LazyEncoder)
+
+    return HttpResponse(result)
+
 
 @permission_required("core.manage_shop", login_url="/login/")
 def add_variants(request, product_id):
     """Adds variants to product with passed product_id based on property/option-
     combinations passed within request body.
     """
-    cache.delete("variants%s" % product_id)
+    cache.delete("%s-variants%s" % (settings.CACHE_MIDDLEWARE_KEY_PREFIX, product_id))
 
     product = Product.objects.get(pk=product_id)
 
@@ -295,33 +347,50 @@ def add_variants(request, product_id):
         if product.has_variant(options):
             continue
 
+        name = request.POST.get("name")
         price = request.POST.get("price")
 
-        slug = ""
+        slug = request.POST.get("slug")
         for option in options:
             property_id, option_id = option.split("|")
             o = PropertyOption.objects.get(pk=option_id)
             slug += "-" + slugify(o.name)
 
-        slug = "%s%s" % (product.slug, slug)
-        sku = "%s-%s" % (product.sku, i+1)
+        slug = "%s-%s" % (product.slug, slug)
+        sku = "%s-%s" % (product.sku, i + 1)
 
-        variant = Product(slug=slug, sku=sku, parent=product, price=price, variant_position=i+1, sub_type=VARIANT)
-        variant.save()
+        variant = None
+        # need to validate the amalgamated slug to make sure it is not already in use
+        try:
+            variant = Product.objects.get(slug=slug)
+            message = _(u"That slug is already in use. Please use another.")
+        except Product.MultipleObjectsReturned:
+            message = _(u"That slug is already in use. Please use another.")
+        except Product.DoesNotExist:
+            variant = Product(name=name, slug=slug, sku=sku, parent=product, price=price, variant_position=(i + 1) * 10, sub_type=VARIANT)
+            try:
+                variant.save()
+            except IntegrityError:
+                continue
 
-        # Save the value for this product and property
-        for option in options:
-            property_id, option_id = option.split("|")
-            pvo = ProductPropertyValue(product = variant, property_id = property_id, value=option_id, type=PROPERTY_VALUE_TYPE_VARIANT)
-            pvo.save()
+            # Save the value for this product and property
+            for option in options:
+                property_id, option_id = option.split("|")
+                pvo = ProductPropertyValue(product=variant, property_id=property_id, value=option_id, type=PROPERTY_VALUE_TYPE_VARIANT)
+                pvo.save()
+
+            message = _(u"Variants have been added.")
+
+    html = (("#variants", manage_variants(request, product_id, as_string=True)),)
 
-    from lfs.manage.views.product.product import selectable_products_inline
     result = simplejson.dumps({
-        "properties" : manage_variants(request, product_id, as_string=True),
-    })
+        "html": html,
+        "message": message,
+    }, cls=LazyEncoder)
 
     return HttpResponse(result)
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def update_variants(request, product_id):
     """Updates/Deletes variants with passed ids (via request body) dependent on
@@ -331,6 +400,7 @@ def update_variants(request, product_id):
 
     action = request.POST.get("action")
     if action == "delete":
+        message = _(u"Variants have been deleted.")
         for key in request.POST.keys():
             if key.startswith("delete-"):
                 try:
@@ -340,10 +410,11 @@ def update_variants(request, product_id):
                     continue
                 else:
                     if product.default_variant == variant:
-                        product.default_variant == None
+                        product.default_variant = None
                         product.save()
                     variant.delete()
     elif action == "update":
+        message = _(u"Variants have been saved.")
         for key, value in request.POST.items():
             if key.startswith("variant-"):
                 id = key.split("-")[1]
@@ -366,20 +437,14 @@ def update_variants(request, product_id):
                         variant.active = True
                     else:
                         variant.active = False
-                    
-                    # active-price    
-                    active_price = request.POST.get("active-price-%s" % id)
-                    if active_price:
-                        variant.active_price = True
-                    else:
-                        variant.active_price = False
 
-                    # active-name    
-                    active_name = request.POST.get("active-name-%s" % id)
-                    if active_name:
-                        variant.active_name = True
-                    else:
-                        variant.active_name = False
+                    # active attributes
+                    for name in ("active_price", "active_sku", "active_name"):
+                        value = request.POST.get("%s-%s" % (name, id))
+                        if value:
+                            setattr(variant, name, True)
+                        else:
+                            setattr(variant, name, False)
 
                     # position
                     position = request.POST.get("position-%s" % id)
@@ -388,6 +453,14 @@ def update_variants(request, product_id):
                     except ValueError:
                         variant.variant_position = 10
 
+                    # default variant
+                    try:
+                        product.default_variant_id = int(request.POST.get("default_variant"))
+                    except TypeError:
+                        pass
+                    else:
+                        product.save()
+
                 variant.save()
 
             elif key.startswith("property"):
@@ -405,19 +478,22 @@ def update_variants(request, product_id):
 
     # Refresh variant positions
     for i, variant in enumerate(product.variants.order_by("variant_position")):
-        variant.variant_position = (i+1) * 10
+        variant.variant_position = (i + 1) * 10
         variant.save()
 
     # Send a signal to update cache
     product_changed.send(product)
 
-    from lfs.manage.views.product.product import selectable_products_inline
+    html = (("#variants", manage_variants(request, product_id, as_string=True)),)
+
     result = simplejson.dumps({
-        "properties" : manage_variants(request, product_id, as_string=True),
-    })
+        "html": html,
+        "message": message,
+    }, cls=LazyEncoder)
 
     return HttpResponse(result)
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def edit_sub_type(request, product_id):
     """Edits the sub type of the variant with given product slug.
@@ -432,7 +508,15 @@ def edit_sub_type(request, product_id):
     # Send a signal to update cache
     product_changed.send(product)
 
-    return HttpResponse(manage_variants(request, product_id))
+    html = (("#variants", manage_variants(request, product_id, as_string=True)),)
+
+    result = simplejson.dumps({
+        "html": html,
+        "message": _(u"Sup type has been saved."),
+    }, cls=LazyEncoder)
+
+    return HttpResponse(result)
+
 
 @permission_required("core.manage_shop", login_url="/login/")
 def update_default_variant(request, product_id):
@@ -447,12 +531,18 @@ def update_default_variant(request, product_id):
     # Send a signal to update cache
     product_changed.send(product)
 
-    return HttpResponse(manage_variants(request, product_id))
+    result = simplejson.dumps({
+        "html": manage_variants(request, product_id, as_string=True),
+        "message": _(u"Default variant has been saved."),
+    }, cls=LazyEncoder)
+
+    return HttpResponse(result)
+
 
 def _refresh_property_positions(product_id):
     """
     """
     # Refresh positions
     for i, product_property in enumerate(ProductsPropertiesRelation.objects.filter(product=product_id)):
-        product_property.position = i*2
-        product_property.save()
\ No newline at end of file
+        product_property.position = i * 2
+        product_property.save()
